package com.biganto.visual.roompark.base

import android.app.Application
import android.util.Log
import com.biganto.visual.roompark.BuildConfig
import com.biganto.visual.roompark.di.koin.initDI
import com.crashlytics.android.Crashlytics
import com.squareup.picasso.Picasso
import timber.log.Timber

/**
 * Created by Vladislav Bogdashkin on 03.09.2019.
 */
class RoomParkApplication : Application() {

    override fun onCreate() {
        super.onCreate()
        initDI()


        if (BuildConfig.DEBUG) Timber.plant(Timber.DebugTree())
        else Timber.plant(CrashlyticsTree())

        val picassoBuilder = Picasso.Builder(this)

        picassoBuilder.listener { _, uri, exception ->
            Timber.e(exception)
            Timber.e(exception, "PICASSO url = %s", uri.toString())
        }

        // Picasso.Builder creates the Picasso object to do the actual requests
        val picasso = picassoBuilder.build()

        try {
            Picasso.setSingletonInstance(picasso)
        } catch (ignored: IllegalStateException) {
            Timber.e(ignored, "PICASSO")
            // Picasso instance was already set
            // cannot set it after Picasso.with(Context) was already in use
        }
    }
}


    private class CrashlyticsTree : Timber.Tree() {
        override fun log(priority: Int, tag: String?, message: String, throwable: Throwable?) {
            if (priority == Log.VERBOSE || priority == Log.DEBUG) return

            Crashlytics.log(priority, tag, message)
            throwable?.let { Crashlytics.logException(it) }
        }
    }